# CHANGELOG



## v0.2.0 (2024-12-06)

### Chore

* chore: update README file ([`afe6932`](https://github.com/opentargets/gentroutils/commit/afe6932d14266d9d266276c1ff9c0458f6b9712a))

* chore: fix author ([`108ea30`](https://github.com/opentargets/gentroutils/commit/108ea3092221f565f3983d44604d3046e761660b))

* chore: added project description and classifiers ([`8ef35fa`](https://github.com/opentargets/gentroutils/commit/8ef35fa58842c5ccac7d69fb5dfb20849d7cdc86))

### Feature

* feat: update default command help ([`c8b2c3a`](https://github.com/opentargets/gentroutils/commit/c8b2c3a390d56bcc07406926ba45080a4b4dd74c))

* feat: remove redundant files from curation update command ([`f3fb1e8`](https://github.com/opentargets/gentroutils/commit/f3fb1e8baed554d6f257ae6f051115ad8e92602f))

### Fix

* fix: use user shell only for installation ([`40129e5`](https://github.com/opentargets/gentroutils/commit/40129e5b6ed88cd21eaa8b0666c1988ae0ef2290))

* fix: upload log file only when not dry-run ([`57c8a8e`](https://github.com/opentargets/gentroutils/commit/57c8a8eafd0deb37221fb990c72e77d9f1c9bf6c))

* fix: use user defined shell ([`0fa2cff`](https://github.com/opentargets/gentroutils/commit/0fa2cff0300cad96f22efdc1584fb68817ed2ac6))

### Unknown

* Merge pull request #19 from opentargets/dev

chore: trigger release process ([`e7bc28c`](https://github.com/opentargets/gentroutils/commit/e7bc28c2fb2464350b46b1f73b11805243421172))

* Merge branch &#39;main&#39; into dev ([`318d141`](https://github.com/opentargets/gentroutils/commit/318d1413f6fc280f6ff727fde3f112bd7f673882))

* Merge pull request #17 from opentargets/dev

chore: trigger release process ([`519aa86`](https://github.com/opentargets/gentroutils/commit/519aa86b8d5de9a93e343d7b93425969439ae7e7))

* Merge pull request #16 from opentargets/dev

chore: trigger release process ([`550b6e8`](https://github.com/opentargets/gentroutils/commit/550b6e8967efa0eac988c1dba7d3c5667439c39b))

* Merge branch &#39;main&#39; into dev ([`e948830`](https://github.com/opentargets/gentroutils/commit/e948830b638032e5da72674ec7298aef42befece))


## v0.1.5 (2024-08-13)

### Ci

* ci: added needs flags to release jobs ([`3b84cdd`](https://github.com/opentargets/gentroutils/commit/3b84cdd3d4e158f172d29ccc27d033facd56e244))

* ci: add pypi release ([`271abbf`](https://github.com/opentargets/gentroutils/commit/271abbfe125f44db11c078f6b3ff91e7748551de))

### Unknown

* Merge pull request #15 from opentargets/dev

chore: trigger release process ([`5740867`](https://github.com/opentargets/gentroutils/commit/57408679669c3e2427df680478baecc7e2873aec))


## v0.1.4 (2024-08-13)

### Ci

* ci: fix link to testpypi ([`aa19be5`](https://github.com/opentargets/gentroutils/commit/aa19be588dcf2e93e862efc9e3ab54e06c3e762e))

### Unknown

* Merge pull request #14 from opentargets/dev

chore: trigger release process ([`bd68b60`](https://github.com/opentargets/gentroutils/commit/bd68b60c81230afe0fbbe49010ef2e130a12353b))


## v0.1.3 (2024-08-13)

### Ci

* ci: fix link to testpypi ([`b14085d`](https://github.com/opentargets/gentroutils/commit/b14085dd05bbb85c3e9a49742f59ff9043c391b0))

### Unknown

* Merge pull request #13 from opentargets/dev

chore: trigger release process ([`79c17d9`](https://github.com/opentargets/gentroutils/commit/79c17d95baf1e7f7cdc0be3137426332b89badc7))


## v0.1.2 (2024-08-13)

### Ci

* ci: use original github token for testpypi ([`1e2e5af`](https://github.com/opentargets/gentroutils/commit/1e2e5af0aba88c4decf8a471d042b3f8c0487414))

### Unknown

* Merge pull request #12 from opentargets/dev

chore: trigger release process ([`48c63ba`](https://github.com/opentargets/gentroutils/commit/48c63ba7ab4753ce8bd2767d53ba32d41257a087))


## v0.1.1 (2024-08-13)

### Ci

* ci: prevent second job run and fix build ([`422b3fc`](https://github.com/opentargets/gentroutils/commit/422b3fc78dcc869c464e0e722be6619dc444de05))

### Unknown

* Merge pull request #11 from opentargets/dev

chore: trigger release process ([`bf30b0d`](https://github.com/opentargets/gentroutils/commit/bf30b0d95b065166620e67c866bb99b067fc7538))


## v0.1.0 (2024-08-13)

### Build

* build: precommit &amp; interrogate ([`8ae6533`](https://github.com/opentargets/gentroutils/commit/8ae6533e757551fbe32d386725deeeb27def2ed7))

* build: docstring linting ([`5feea17`](https://github.com/opentargets/gentroutils/commit/5feea17a28241dd7f4ecd43ebb7c4e34e0fd8301))

* build: added deptry ([`179f196`](https://github.com/opentargets/gentroutils/commit/179f196e766185ba8a54a5292a2aedf80e45b4ab))

* build: added mypy ([`ccf0750`](https://github.com/opentargets/gentroutils/commit/ccf07504df5350063ad0c3cdc1e38876a14f5507))

* build: added pydoclint ([`633b3da`](https://github.com/opentargets/gentroutils/commit/633b3da1623c41da519c9ad5f0caf747648a051e))

* build: ruff setup ([`daddc69`](https://github.com/opentargets/gentroutils/commit/daddc6949bb2d8e39783e2837a85a3b853825590))

* build: dev setup make target ([`0dda8bd`](https://github.com/opentargets/gentroutils/commit/0dda8bdab571d925e2a42e66fa0dc7809b2da68f))

### Chore

* chore: licence badge ([`93708ba`](https://github.com/opentargets/gentroutils/commit/93708bad3bbc1d65cc0f87faad4cbe14856bbf93))

* chore: badge ([`d92782b`](https://github.com/opentargets/gentroutils/commit/d92782b8ccced842e8fa853f00c298b432e759c8))

* chore: added licence ([`bac9b9d`](https://github.com/opentargets/gentroutils/commit/bac9b9d20279ce08623571fa29bf43d8d63fab83))

### Ci

* ci: fix repo name in checkout action for tag ([`c49ee91`](https://github.com/opentargets/gentroutils/commit/c49ee911455468650a4e7230543c9060739c9182))

* ci: fix path to the semvar version ([`614f3a7`](https://github.com/opentargets/gentroutils/commit/614f3a753fb562264fb05189ee27c16a522cfcbc))

* ci: trigger release from main branch ([`9447be8`](https://github.com/opentargets/gentroutils/commit/9447be8627108b7924bcad0750d7c53f2babb100))

* ci: skip no-commit-to-branch on dev test ([`e214f6c`](https://github.com/opentargets/gentroutils/commit/e214f6c657eae9ed519cf552fc03639396cb2d45))

* ci: added manual trigger for release trigger job ([`911ba3f`](https://github.com/opentargets/gentroutils/commit/911ba3f42a81055dd006c8f1020ffdb315357eac))

* ci: improvements over dev branch tests&#34; ([`4597b90`](https://github.com/opentargets/gentroutils/commit/4597b90227306822718c0364db8d8a336282cc95))

* ci: fix trigger date ([`da168b7`](https://github.com/opentargets/gentroutils/commit/da168b7153a5b0eb03319e0a248a704604bb9cca))

* ci: changed ga workflow names ([`caab806`](https://github.com/opentargets/gentroutils/commit/caab806457f36c84556422ef61eeed6a219e6bb6))

* ci: release schedule test ([`eaa132e`](https://github.com/opentargets/gentroutils/commit/eaa132ea06694110b969bd4b079f96f32ae80078))

* ci: release schedule test ([`c43d2ab`](https://github.com/opentargets/gentroutils/commit/c43d2ab659ddbc7ec2e22c2c1a07d136a725e4d5))

* ci: changed how uv and rye are installed ([`e7c9e5e`](https://github.com/opentargets/gentroutils/commit/e7c9e5e2dec910aa9cef2b14b1d88d4e669c057a))

* ci: ci test release ([`8c98b46`](https://github.com/opentargets/gentroutils/commit/8c98b46b40e5779eb789b3b510d0352dc45a34f0))

* ci: pr yaml ([`c65f137`](https://github.com/opentargets/gentroutils/commit/c65f1379d45bd1f1437fa816fa6fb4e5ae5f4737))

### Documentation

* docs: added documentation over the cli ([`fff60a9`](https://github.com/opentargets/gentroutils/commit/fff60a91a933d075989803f570fea0c8d64ec50c))

* docs: readme scheleton ([`c3c7887`](https://github.com/opentargets/gentroutils/commit/c3c7887f633e89fb153ffd2a8981442e6fb58b92))

### Feature

* feat: added DEV environment ([`6a44a9e`](https://github.com/opentargets/gentroutils/commit/6a44a9ede2a9b56a3f58873f458a1843abc3b422))

* feat: local pre-commit execution without action ([`4345691`](https://github.com/opentargets/gentroutils/commit/4345691c7e3a352b72d5003fbfe5781d7d111c90))

* feat: attempt to install rye with cargo ([`ce4fd37`](https://github.com/opentargets/gentroutils/commit/ce4fd37ed2483c353bc552e6d9e91b5f9883dc52))

* feat: gwas curation update script ([`31716bf`](https://github.com/opentargets/gentroutils/commit/31716bf7a62c097e19305023f9023b7338e404ee))

* feat: pytest setup and cli entrypoint ([`c107abd`](https://github.com/opentargets/gentroutils/commit/c107abd843efc6a60c6604e22ca5994fe46d3617))

* feat: package setup ([`0c5d4c3`](https://github.com/opentargets/gentroutils/commit/0c5d4c3186ae6ddc18f46e0e76ad690e08c8ec56))

### Fix

* fix: fix dev branch test run ([`8430526`](https://github.com/opentargets/gentroutils/commit/8430526f911fbe91c58131056f091cbd11ef2e15))

* fix: fix dev branch test run ([`967c0b8`](https://github.com/opentargets/gentroutils/commit/967c0b83d3e1c4f6e9c7c2d909fbb71674ec8871))

* fix: run pre-commit by rye ([`7fbd06c`](https://github.com/opentargets/gentroutils/commit/7fbd06cbeb42563f6c2a66f768e490f554a7c07b))

* fix: typo in package name ([`10584a5`](https://github.com/opentargets/gentroutils/commit/10584a56790cf4693bd47ee3e50672bc4bb78068))

* fix: ensure pip is installed for pre-commit action ([`7d74378`](https://github.com/opentargets/gentroutils/commit/7d74378a45c307b9ae64cd6dfd707948113b5e7d))

* fix: debug v2 ([`332e0d5`](https://github.com/opentargets/gentroutils/commit/332e0d58dee315c9aa5f57f20464d1097c41cb59))

* fix: debug ci ([`cd0c7ed`](https://github.com/opentargets/gentroutils/commit/cd0c7eda865af9df5bf1ab65dfa405b3a13e605c))

* fix: add cargo to rc file ([`7e1340f`](https://github.com/opentargets/gentroutils/commit/7e1340f1fb4aa57092f149db0e9400d18a4a0cca))

* fix: moved ci file ([`c2626a2`](https://github.com/opentargets/gentroutils/commit/c2626a2479217e1e0e4a36470503d3a1f19f3021))

* fix: remove local log file ([`b2a80fc`](https://github.com/opentargets/gentroutils/commit/b2a80fceceeb34832ddc271c28c8de9363e3b745))

### Unknown

* Merge pull request #10 from opentargets/dev

chore: trigger release process ([`0369439`](https://github.com/opentargets/gentroutils/commit/03694399a0f1f412950c81eb6a68e46af1be383d))

* Merge branch &#39;main&#39; into dev ([`6d40028`](https://github.com/opentargets/gentroutils/commit/6d400282725abf414dba86f2d4cfda3b2a317c75))

* Merge pull request #9 from opentargets/dev

chore: trigger release process ([`59321a9`](https://github.com/opentargets/gentroutils/commit/59321a90ab91ea4d9d605db7ded429df932fa2e9))

* Merge pull request #8 from opentargets/dev

chore: trigger release process ([`d767f55`](https://github.com/opentargets/gentroutils/commit/d767f55bf5d5b895915415b54699d2a54d83fb5d))

* Merge pull request #7 from opentargets/dev

chore: trigger release process ([`e0eea67`](https://github.com/opentargets/gentroutils/commit/e0eea67f21a0b1e1c72be8b5b2d139029a5f7f51))

* Merge branch &#39;main&#39; into dev ([`9669a40`](https://github.com/opentargets/gentroutils/commit/9669a405838289e8869c9f861e03134a65cf6825))

* Merge pull request #6 from opentargets/dev

chore: trigger release process ([`80475d0`](https://github.com/opentargets/gentroutils/commit/80475d0f727c93f67cb190537e16104752f1b9b2))

* Merge pull request #5 from opentargets/new-branch

ci: fix trigger date ([`f0550ea`](https://github.com/opentargets/gentroutils/commit/f0550eac15663684cbfe61725c7f669d0a54f7e8))

* Merge branch &#39;dev&#39; into new-branch ([`7079a77`](https://github.com/opentargets/gentroutils/commit/7079a7730972409ccd844d53b11b504a8d7740a0))

* Merge pull request #4 from opentargets/new-branch

ci: changed ga workflow names ([`e8d9650`](https://github.com/opentargets/gentroutils/commit/e8d96501481b76c6b0704de73e54c8b6977af12a))

* Merge branch &#39;dev&#39; into new-branch ([`75ec3da`](https://github.com/opentargets/gentroutils/commit/75ec3da21cb2ba1ef5e2d4101503f2769ff46562))

* Merge pull request #3 from opentargets/new-branch

ci: release schedule test ([`70389bb`](https://github.com/opentargets/gentroutils/commit/70389bb666079c15dbb84ebc0acf1cb9fdec1ee5))

* Merge branch &#39;dev&#39; into new-branch ([`0fa0ec6`](https://github.com/opentargets/gentroutils/commit/0fa0ec66a129d53f40f7acbe74d15044303efaba))

* Merge pull request #2 from opentargets/new-branch

ci: release schedule test ([`10ba02a`](https://github.com/opentargets/gentroutils/commit/10ba02afd97595a9148a7e07bdfaaa5bb194f4b0))

* Merge branch &#39;dev&#39; into new-branch ([`5f8e943`](https://github.com/opentargets/gentroutils/commit/5f8e9438c7f88c6d54c591d8e7ce3899efcf7a7d))

* Merge pull request #1 from opentargets/new-branch

ci: ci test release ([`1e07aa5`](https://github.com/opentargets/gentroutils/commit/1e07aa5cd4860c1c6c996b953a836f19028580db))
